<?php
define('DATABASE_PATH', 'viewcounts.sqlite');
define('VIEWS_TABLE', 'views');
define('CRAWLER_TABLE', 'crawlers');

$crawlerRegex = '/(bot|crawl|spider|face|google|ahref|yahoo|python)/i'; // case-insensitive regex matching

// get the image URL without query strings
function getImageUrl() {
    return strtok($_SERVER['REQUEST_URI'], '?');
}

function getPdo() {
    $pdo = new PDO('sqlite:' . DATABASE_PATH);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    return $pdo;
}

function updateViewCounts($pdo, $imageUrl) {
    $stmt = $pdo->prepare("
        INSERT INTO " . VIEWS_TABLE . " (image_url, count)
        VALUES (:image_url, 1)
        ON CONFLICT(image_url) DO UPDATE SET count = count + 1
    ");
    $stmt->bindParam(':image_url', $imageUrl);
    $stmt->execute();
}

function incrementCrawlerCount($pdo) {
    // Check if the crawler count already exists in the table
    $stmt = $pdo->prepare("SELECT count FROM " . CRAWLER_TABLE . " LIMIT 1");
    $stmt->execute();
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($result) {
        // If the row exists, update the count
        $stmt = $pdo->prepare("UPDATE " . CRAWLER_TABLE . " SET count = count + 1");
        $stmt->execute();
    } else {
        // If no row exists, insert a new row with count = 1
        $stmt = $pdo->prepare("INSERT INTO " . CRAWLER_TABLE . " (count) VALUES (1)");
        $stmt->execute();
    }
}

$imageUrl = getImageUrl();
$imagePath = substr($imageUrl, 1); // Remove the leading slash

if (!file_exists($imagePath)) {
    header('HTTP/1.1 404 Not Found');
    header('Content-Type: text/plain');
    exit('Image not found');
}

$pdo = getPdo();

// Check if the user agent matches the regular expression for crawlers
$isCrawler = false;
$userAgent = $_SERVER['HTTP_USER_AGENT'];

if (preg_match($crawlerRegex, $userAgent)) {
    // It's a crawler, increment crawler count in the database
    $isCrawler = true;
    incrementCrawlerCount($pdo);
} else {
    // It's a regular user, update the normal view counts
    if (strpos($imageUrl, '/.thumb/') === false) {
        updateViewCounts($pdo, $imageUrl);
    }
}

// Serve the image as usual
$imageMimeType = mime_content_type($imagePath);
header('Content-Type: ' . $imageMimeType);
header('Content-Length: ' . filesize($imagePath));
readfile($imagePath);
?>
